//===--- catch-byvalue.h - test input file for iwyu -----------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is distributed under the University of Illinois Open Source
// License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef INCLUDE_WHAT_YOU_USE_TESTS_CXX_CATCH_BYVALUE_H_
#define INCLUDE_WHAT_YOU_USE_TESTS_CXX_CATCH_BYVALUE_H_

class CatchByValue {};

#endif // INCLUDE_WHAT_YOU_USE_TESTS_CXX_CATCH_BYVALUE_H_
